@@ -1,7 +1,6 @@
 """
 Command to run a pangeo-forge recipe
 """
-import tempfile
 from datetime import datetime
 from pathlib import Path
 
@@ -78,8 +77,8 @@ class Bake(BaseCommand):
     )
 
     container_image = Unicode(
-        # Provides apache_beam 2.41, which we pin to in setup.py
-        "pangeo/forge:7c87e6c",
+        # Provides apache_beam 2.42, which we pin to in setup.py
+        "quay.io/pangeo/forge:2022.10.20",
         config=True,
         help="""
         Container image to use for this job.
@@ -111,12 +110,8 @@ class Bake(BaseCommand):
             extra={"status": "setup"},
         )
 
-        # Create a temporary directory where we fetch the feedstock repo and perform all operations
-        # FIXME: Support running this on an already existing repository, so users can run it
-        # as they develop their feedstock
-        with tempfile.TemporaryDirectory() as d:
-            self.fetch(d)
-            feedstock = Feedstock(Path(d) / self.feedstock_subdir)
+        with self.fetch() as checkout_dir:
+            feedstock = Feedstock(Path(checkout_dir) / self.feedstock_subdir)
 
             self.log.info("Parsing recipes...", extra={"status": "running"})
             with redirect_stderr(self.log, {"status": "running"}), redirect_stdout(
@@ -140,7 +135,7 @@ class Bake(BaseCommand):
                 # Unique name for running this particular recipe.
                 if not self.job_name:
                     # FIXME: Should include the name of repo / ref as well somehow
-                    job_name = f"{name}-{recipe.sha256().hex()}-{int(datetime.now().timestamp())}"
+                    job_name = f"{name}-{recipe.sha256.hex()}-{int(datetime.now().timestamp())}"
                 else:
                     job_name = self.job_name
 
