@@ -1,5 +1,9 @@
 import logging
+import os
 import sys
+import tempfile
+from collections.abc import Generator
+from contextlib import contextmanager
 
 from pythonjsonlogger import jsonlogger
 from repo2docker import contentproviders
@@ -122,38 +126,50 @@ class BaseCommand(Application):
         """,
     )
 
-    def fetch(self, target_path):
+    @contextmanager
+    def fetch(self) -> Generator[str, None, None]:
         """
-        Fetch repo from url at ref, and check it out to checkout_path
+        Fetch repo from configured url at ref, and return a directory where it can be accessed.
 
-        Uses repo2docker to detect what kinda url is going to be checked out,
-        and fetches it into checkout_path. No image building or anything is
-        performed.
-
-        checkout_path should be empty.
+        If self.repo is a local directory that exists, it is just returned - no extra
+        processing is done. If not, repo2docker is used to detect what kind of URL
+        is to be checked out (git, zenodo, mercurial, etc) and that is checked out into
+        a temporary directory, the path of which is returned. When the contextmanager
+        exits, the temporary directory is cleaned up.
         """
-        picked_content_provider = None
-        for ContentProvider in self.content_providers:
-            cp = ContentProvider()
-            spec = cp.detect(self.repo, ref=self.ref)
-            if spec is not None:
-                picked_content_provider = cp
-                self.log.info(
-                    "Picked {cp} content "
-                    "provider.\n".format(cp=cp.__class__.__name__),
-                    extra={"status": "fetching"},
+        if os.path.exists(self.repo):
+            # We are trying to submit off a local checkout, so we don't need to do much
+            checkout_dir = self.repo
+
+            yield checkout_dir
+
+            # No cleanup necessary
+            return
+        with tempfile.TemporaryDirectory() as checkout_dir:
+            picked_content_provider = None
+            for ContentProvider in self.content_providers:
+                cp = ContentProvider()
+                spec = cp.detect(self.repo, ref=self.ref)
+                if spec is not None:
+                    picked_content_provider = cp
+                    self.log.info(
+                        "Picked {cp} content "
+                        "provider.\n".format(cp=cp.__class__.__name__),
+                        extra={"status": "fetching"},
+                    )
+                    break
+
+            if picked_content_provider is None:
+                raise ValueError(
+                    f"Could not fetch {self.repo}, no matching contentprovider found"
                 )
-                break
 
-        if picked_content_provider is None:
-            raise ValueError(
-                f"Could not fetch {self.repo}, no matching contentprovider found"
-            )
+            for log_line in picked_content_provider.fetch(
+                spec, checkout_dir, yield_output=True
+            ):
+                self.log.info(log_line, extra=dict(status="fetching"))
 
-        for log_line in picked_content_provider.fetch(
-            spec, target_path, yield_output=True
-        ):
-            self.log.info(log_line, extra=dict(status="fetching"))
+            yield checkout_dir
 
     def json_excepthook(self, etype, evalue, traceback):
         """
